@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use base qw( Exporter );
 
-our $VERSION = '0.15_05';
+our $VERSION = '0.15_06';
 
 use AnyEvent::Stomper;
 use AnyEvent::Stomper::Error;
@@ -44,6 +44,7 @@ sub new {
   $self->{on_node_connect}    = $params{on_node_connect};
   $self->{on_node_disconnect} = $params{on_node_disconnect};
   $self->{on_node_error}      = $params{on_node_error};
+  $self->on_error( $params{on_error} );
 
   my %node_params;
   foreach my $name ( qw( login passcode vhost heartbeat connection_timeout
@@ -76,7 +77,7 @@ sub execute {
   no strict qw( refs );
 
   foreach my $name ( qw( send subscribe unsubscribe ack nack begin commit
-      abort ) )
+      abort disconnect ) )
   {
     *{$name} = sub {
       my $self = shift;
@@ -102,6 +103,26 @@ sub nodes {
   return values %{ $self->{_nodes_pool} };
 }
 
+sub on_error {
+  my $self = shift;
+
+  if (@_) {
+    my $on_error = shift;
+
+    if ( defined $on_error ) {
+      $self->{on_error} = $on_error;
+    }
+    else {
+      $self->{on_error} = sub {
+        my $err = shift;
+        warn $err->message . "\n";
+      };
+    }
+  }
+
+  return $self->{on_error};
+}
+
 sub force_disconnect {
   my $self = shift;
 
@@ -233,6 +254,20 @@ sub _prepare {
     %cbs,
   };
 
+  unless ( defined $cmd->{on_receipt} ) {
+    weaken($self);
+
+    $cmd->{on_receipt} = sub {
+      my $receipt = shift;
+      my $err     = shift;
+
+      if ( defined $err ) {
+        $self->{on_error}->($err);
+        return;
+      }
+    };
+  }
+
   return $cmd;
 }
 
@@ -271,16 +306,12 @@ sub _execute {
           return;
         }
 
-        if ( defined $cmd->{on_receipt} ) {
-          $cmd->{on_receipt}->( $receipt, $err );
-        }
+        $cmd->{on_receipt}->( $receipt, $err );
 
         return;
       }
 
-      if ( defined $cmd->{on_receipt} ) {
-        $cmd->{on_receipt}->($receipt);
-      }
+      $cmd->{on_receipt}->($receipt);
     },
 
     defined $cmd->{on_message}
@@ -413,7 +444,9 @@ AnyEvent::Stomper::Cluster is the client for the cluster of STOMP servers.
 =item nodes => \@nodes
 
 Specifies the list of nodes. Parameter should contain array of hashes. Each
-hash should contain C<host> and C<port> elements.
+hash should contain C<host> and C<port> elements. The client gets one random
+node from this list, connects to it and sends all frames to this node. If
+current active node fails, the client gets next node from the list.
 
 =item login => $login
 
@@ -811,11 +844,11 @@ The method C<abort> is used to roll back a transaction.
 
 =head2 disconnect( [ %params ] [, $cb->( $receipt, $err ) ] )
 
-A client can disconnect from the server at anytime by closing the socket but
-there is no guarantee that the previously sent frames have been received by
-the server. To do a graceful shutdown, where the client is assured that all
-previous frames have been received by the server, you must call C<disconnect>
-method and wait for the C<RECEIPT> frame.
+A client can disconnect from the сurrent active node at anytime by closing the
+socket but there is no guarantee that the previously sent frames have been
+received by the node. To do a graceful shutdown, where the client is assured
+that all previous frames have been received by the node, you must call
+C<disconnect> method and wait for the C<RECEIPT> frame.
 
 =head2 execute( $command, [ %params ] [, $cb->( $receipt, $err ) ] )
 
@@ -865,6 +898,10 @@ Gets node by host and port.
 
 Gets all available nodes.
 
+=head2 on_error( [ $callback ] )
+
+Gets or sets the C<on_error> callback.
+
 =head2 force_disconnect()
 
 The method for forced disconnection. All uncompleted operations will be
